@@ -2,19 +2,19 @@
 """ base api """
 from typing import Optional
 import wenxin_api
+import wenxin_api.variable
 from wenxin_api import requestor, error
 from wenxin_api.base_object import BaseObject
 from wenxin_api.const import ERNIE_1P5B_MODEL
-from wenxin_api.variable import API_REQUEST_URLS
 from wenxin_api.error import IllegalRequestArgumentError, InvalidResponseValue
 
 class APIBaseObject(BaseObject):
-    base_api_urls = API_REQUEST_URLS
+    wenxin_api.variable.API_REQUEST_URLS
 
     def __init__(self, 
                  ak=None, 
                  sk=None, 
-                 api_type=0, 
+                 api_type=None, 
                  base_model=ERNIE_1P5B_MODEL,
                  **params):
         super(APIBaseObject, self).__init__(**params)
@@ -23,21 +23,28 @@ class APIBaseObject(BaseObject):
         self.__setattr__("api_type", api_type)
         self.__setattr__("base_model", base_model)
 
+    @classmethod
+    def construct_from(cls, **values):
+        instance = cls(**values)
+        return instance
+
     @classmethod
     def default_request(
         cls,
         ak=None,
         sk=None,
+        api_type=None,
         method="post",
-        api_type=0,
         request_id=None,
         request_type=None,
         files=None,
         **params,
     ):
+        if api_type is None:
+            api_type = cls.api_type
         try:
             api_type = int(api_type)
-            url = cls.base_api_urls[api_type]
+            url = wenxin_api.variable.API_REQUEST_URLS[api_type]
         except:
             raise IllegalRequestArgumentError()
         if request_type is None:
@@ -50,10 +57,11 @@ class APIBaseObject(BaseObject):
         return resp
     
     @classmethod
-    def get_url(cls, api_type=0):
+    def get_url(cls, api_type=None):
         try:
-            api_type = int(api_type)
-            url = cls.base_api_urls[api_type]
+            if api_type is None:
+                api_type = cls.api_type
+            url = wenxin_api.variable.API_REQUEST_URLS[api_type]
         except:
             raise IllegalRequestArgumentError("api_type: {}".format(api_type))
         return url
@@ -61,7 +69,7 @@ class APIBaseObject(BaseObject):
 class CreatableAPIObject(APIBaseObject):
     """ creatable api object """
     @classmethod
-    def create(cls, ak=None, sk=None, api_type=0, request_id=None, **params):
+    def create(cls, ak=None, sk=None, api_type=None, request_id=None, **params):
         """ create """
         if isinstance(cls, APIBaseObject):
             raise ValueError(".create may only be called as a class method now.")
@@ -72,12 +80,12 @@ class CreatableAPIObject(APIBaseObject):
         resp = http_requestor.request(url, method, request_id=request_id, **params)
         if not isinstance(resp, BaseObject):
             raise InvalidResponseValue("create method should returns BaseObject instance")
-        return cls.construct_from(resp)
+        return cls.construct_from(**resp, api_type=api_type)
 
 class DeletableAPIObject(APIBaseObject):
     """ deletable api object """
     @classmethod
-    def delete(cls, ak=None, sk=None, api_type=0, request_id=None, **params):
+    def delete(cls, ak=None, sk=None, api_type=None, request_id=None, **params):
         if isinstance(cls, APIBaseObject):
             raise ValueError(".delete may only be called as a class method now.")
         request_type = params.pop("type", None)
@@ -87,12 +95,12 @@ class DeletableAPIObject(APIBaseObject):
         resp = http_requestor.request(url, method, request_id=request_id, **params)
         if not isinstance(resp, BaseObject):
             raise InvalidResponseValue("delete method should returns BaseObject instance")
-        return cls.construct_from(resp)
+        return cls.construct_from(api_type=api_type, **resp)
 
 class StopableAPIObject(APIBaseObject):
     """ stopable api object """
     @classmethod
-    def stop(cls, ak=None, sk=None, api_type=0, request_id=None, **params):
+    def stop(cls, ak=None, sk=None, api_type=None, request_id=None, **params):
         request_type = params.pop("type", None)
         method = params.pop("method", "post")
         http_requestor = requestor.HTTPRequestor(ak, sk, request_type)
@@ -100,12 +108,12 @@ class StopableAPIObject(APIBaseObject):
         resp = http_requestor.request(url, method, request_id=request_id, **params)
         if not isinstance(resp, BaseObject):
             raise InvalidResponseValue("stop method should returns BaseObject instance")
-        return cls.construct_from(resp)
+        return cls.construct_from(api_type=api_type, **resp)
 
 class ListableAPIObject(APIBaseObject):
     """ listable api object """
     @classmethod
-    def list(cls, ak=None, sk=None, api_type=0, request_id=None, **params):
+    def list(cls, ak=None, sk=None, api_type=None, request_id=None, **params):
         request_type = params.pop("type", None)
         method = params.pop("method", "post")
         if request_type is None:
@@ -114,14 +122,14 @@ class ListableAPIObject(APIBaseObject):
         url = cls.get_url(api_type)
         resps = http_requestor.request(url, method, request_id=request_id, **params)
         if isinstance(resps, BaseObject):
-            return [cls.construct_from(resps)]
-        resp = [cls.construct_from(r) for r in resps]
+            return [cls.construct_from(**resps, api_type=api_type)]
+        resp = [cls.construct_from(**r, api_type=api_type) for r in resps]
         return resp
 
 class RetrievalableAPIObject(APIBaseObject):
     """ retrievalable api object """
     @classmethod
-    def retrieve(cls, ak=None, sk=None, api_type=0, request_id=None, **params):
+    def retrieve(cls, ak=None, sk=None, api_type=None, request_id=None, **params):
         if "type" not in params:
             raise IllegalRequestArgumentError("type is not provided")
         request_type = params.pop("type", None)
@@ -131,4 +139,4 @@ class RetrievalableAPIObject(APIBaseObject):
         resp = http_requestor.request(url, method, request_id=request_id, **params)
         if not isinstance(resp, BaseObject):
             raise InvalidResponseValue("retrieve method should returns BaseObject instance")
-        return cls.construct_from(resp)
\ No newline at end of file
+        return cls.construct_from(api_type=api_type, **resp)
\ No newline at end of file
