@@ -102,5 +102,12 @@ TASK_STATE_INFER_IN_QUEUE = TASK_STATE_INFER_BASE + 1
 TASK_STATE_INFER_RUNNING = TASK_STATE_INFER_BASE + 2
 TASK_STATE_INFER_END = TASK_STATE_INFER_BASE + 3
 
+# 
+TYPE_TEXT_TO_IMAGE = 12
+
 # file
 FILE_LINE_UPPER_BOUND = 1000
+
+# source
+SOURCE_WENXIN = 1
+SOURCE_CONSOLE = 2
\ No newline at end of file
