@@ -1,10 +1,13 @@
 """ init """
-from wenxin_api.tasks.text_to_image import TextToImage
+from wenxin_api.tasks.text_to_image import TextToImage, TextToImageRef, TextToImageConsole
 from wenxin_api.tasks.cloze import Cloze
 from wenxin_api.tasks.composition import Composition
 from wenxin_api.tasks.couplet import Couplet
 from wenxin_api.tasks.free_qa import FreeQA
 from wenxin_api.tasks.novel import Novel
 from wenxin_api.tasks.official_documents import OfficialDocuments
+from wenxin_api.tasks.paraphrase import Paraphrase
 from wenxin_api.tasks.summarization import Summarization
-from wenxin_api.tasks.text_generation import TextGeneration
\ No newline at end of file
+from wenxin_api.tasks.qa_extract import QAExtract
+from wenxin_api.tasks.text_generation import TextGeneration
+from wenxin_api.tasks.query_generation import QueryGeneration
